/*
* Copyright 2015 Riccardo Padovani <riccardo@rpadovani.com>
*
* This file is part of falldown.
*
* falldown is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; version 3.
*
* falldown is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/

import QtQuick 2.3
import QtQuick.Layouts 1.1

import Ubuntu.Components 1.3
import Bacon2D 1.0

import "../js/game.js" as Game

Scene {
    // XXX https://github.com/Bacon2D/Bacon2D/issues/114
    //physics: true
    Component.onCompleted: physics = true

    Image {
        source: Qt.resolvedUrl("../img/board/background-tile.png")
        anchors.fill: parent
        fillMode: Image.Tile
    }

    ColumnLayout {
        anchors.fill: parent
        spacing: units.gu(3)

        Item {
            Layout.fillWidth: true
            Layout.preferredHeight: units.gu(3)

            Image {
                source: Qt.resolvedUrl("../img/ui/top-menu-back.png")

                fillMode: Image.TileHorizontally
                anchors {
                    left: parent.left
                    right: parent.right
                    bottom: parent.bottom
                }
            }
        }

        Image {
            source: Qt.resolvedUrl("../img/ui/title.png")

            Layout.alignment : Qt.AlignHCenter
            Layout.preferredWidth: parent.width / 1.25
            Layout.preferredHeight: units.gu(10)

            Image {
                source: Qt.resolvedUrl("../img/board/ball-back.png")

                anchors {
                    left: parent.horizontalCenter
                    bottom: parent.bottom
                    bottomMargin: parent.height / 20
                }

                height: units.gu(5)
                width: height

                Image {
                    anchors.fill: parent
                    source: Qt.resolvedUrl("../img/board/ball-smile.png")
                }
            }

            Text {
                anchors {
                    top: parent.bottom
                    left: parent.left
                    leftMargin: units.gu(1.5)
                }

                text: "v " + version
                color: "#E69F00"
            }
        }

        Image {
            source: Qt.resolvedUrl("../img/ui/score_back.png")

            Layout.fillWidth: true
            Layout.preferredHeight: parent.width / 4.3

            Text {
                text: settings.highScore

                anchors.fill: parent
                anchors.topMargin: parent.height / 5
                horizontalAlignment: Text.AlignHCenter
            }
        }

        AbstractButton {
            Layout.fillWidth: true
            Layout.fillHeight: true

            Image {
                source: Qt.resolvedUrl("../img/ui/play-btn.png")

                height: units.gu(10)
                width: height

                anchors.centerIn: parent
            }

            onClicked: Game.startGame()
        }

        Item {
            Layout.fillWidth: true
            Layout.preferredHeight: units.gu(15)

            AbstractButton {
                width: parent.width / 2
                height: units.gu(10)

                anchors.left: parent.left

                onClicked: settings.mute = !settings.mute

                Image {
                    source: settings.mute ?
                                Qt.resolvedUrl("../img/ui/sound-on-btn-home.png") :
                                Qt.resolvedUrl("../img/ui/sound-off-btn-home.png")

                    height: units.gu(10)
                    width: height

                    anchors.horizontalCenter: parent.horizontalCenter
                }
            }

            AbstractButton {
                width: parent.width / 2
                height: units.gu(10)

                anchors.right: parent.right

                onClicked: game.currentScene = aboutScene

                Image {
                    source: Qt.resolvedUrl("../img/ui/info-btn-home.png")

                    height: units.gu(10)
                    width: height

                    anchors.centerIn: parent
                }
            }
        }
    }
}
